Crate typst_eval

Crate typst_eval 

Typst’s code interpreter.

Structs

CapturesVisitor
A visitor that determines which variables to capture for a closure.
Vm
A virtual machine.

Enums

FlowEvent
A control flow event that occurred during evaluation.

Traits

Eval
Evaluate an expression.

Functions

eval
Evaluate a source file and return the resulting module.
eval_closure
Call the function in the context with the arguments.
eval_string
Evaluates a string in the given syntax mode and returns the resulting value.
hint_if_shadowed_std
Provide a hint if the callee is a shadowed standard library function.
import
Process an import of a package or file relative to the current location.