Typst’s code interpreter.
Structs
- Captures
Visitor - A visitor that determines which variables to capture for a closure.
- Vm
- A virtual machine.
Enums
- Flow
Event - A control flow event that occurred during evaluation.
Traits
- Eval
- Evaluate an expression.
Functions
- eval
- Evaluate a source file and return the resulting module.
- eval_
closure - Call the function in the context with the arguments.
- eval_
string - Evaluates a string in the given syntax
modeand returns the resulting value. - hint_
if_ shadowed_ std - Provide a hint if the callee is a shadowed standard library function.
- import
- Process an import of a package or file relative to the current location.